<?php

switch ($messaggio) {

case "Modifica o cancella la prenotazione":                              $messaggio = "&Auml;ndern oder L&ouml;schen von Reservierungen"; break;
case "Prenotazione a nome di":                                           $messaggio = "Reservierung f&uuml;r"; break;
case "nato il":                                                          $messaggio = "geboren am"; break;
case "nata il":                                                          $messaggio = "geboren am"; break;
case "e":                                                                $messaggio = "und"; break;
case "CAP":                                                              $messaggio = "Postleitzahl"; break;
case "Telefono":                                                         $messaggio = "Telefon"; break;
case "2º telefono":                                                     $messaggio = "Mobiltelefon"; break;
case "3º telefono":                                                     $messaggio = "2. Telefon"; break;
case "Modifica i dati del cliente":                                      $messaggio = "Kundendaten &auml;ndern"; break;
case "La prenotazione è dell'anno precedente, si potrà modificare solo la data finale":        $messaggio = "Die Reservierung ist vom letzten Jahr, es ist nur m&ouml;glich das Enddatum zu &auml;ndern."; break;
case "settimane":                                                        $messaggio = "Wochen"; break;
case "giorni":                                                           $messaggio = "Tage"; break;
case "dal":                                                              $messaggio = "von"; break;
case "al":                                                               $messaggio = "bis"; break;
case "cambia in":                                                        $messaggio = ""; break;    // neu, ndern in case "Appartamento":                                                     $messaggio = "Apartment"; break;
case "in":                                                               $messaggio = "in"; break;
case "Nº di piano":                                                     $messaggio = "Flur Nummer"; break;
case "e/o di casa":                                                      $messaggio = "und/oder Hausnummer"; break;
case "e/o di persone":                                                   $messaggio = "und/oder Personenzahl"; break;
case "Nº di persone":                                                   $messaggio = "Personen"; break;
case "Commento":                                                         $messaggio = "Kommentar"; break;
case "Cancella il commento":                                             $messaggio = "Kommentar l&ouml;schen"; break;
case "Tipo di tariffa":                                                  $messaggio = "Tarif"; break;
case "tariffa":                                                          $messaggio = "Preis"; break;
case "Sconto":                                                           $messaggio = "Rabatt"; break;
case "Caparra":                                                          $messaggio = "Anzahlung"; break;
case "resto":                                                            $messaggio = "Rest"; break;
case "Ricalcola la caparra in base alla nuova tariffa":                  $messaggio = "Anzahlung automatisch errechnen"; break;
case "moltiplicato per":                                                 $messaggio = "multipliziert mit"; break;
case "Costo aggiuntivo settimanale":                                     $messaggio = "w&ouml;chentliche Aufschl&auml;ge"; break;
case "Costo aggiuntivo giornaliero":                                     $messaggio = "t&auml;gliche Aufschl&auml;ge"; break;
case "per":                                                              $messaggio = "f&uuml;r"; break;
case "settimane moltiplicato per":                                       $messaggio = "Wochen multipliziert mit"; break;
case "giorni moltiplicato per":                                          $messaggio = "Tage multipliziert mit"; break;
case "della tariffa moltiplicato per":                                   $messaggio = "des Preises multipliziert mit"; break;
case "Prenotazione confermata":                                          $messaggio = "Reservierung best&auml;tigt"; break;
case "Totale da pagare":                                                 $messaggio = "Gesamt zu zahlen"; break;
case "Pagato":                                                           $messaggio = "Bezahlt"; break;
case "aggiungi":                                                         $messaggio = "addieren"; break;
case "pagato tutto":                                                     $messaggio = "alles bezahlt"; break;
case "caparra ":                                                         $messaggio = "Anzahlung bezahlt"; break;
case "Ancora da pagare":                                                 $messaggio = "Noch zu bezahlen"; break;
case "Nuovo costo aggiuntivo unico":                                     $messaggio = "Neue einheitliche Geb&uuml;hr festlegen"; break;
case "di":                                                               $messaggio = "von"; break;
case "da moltiplicare per":                                              $messaggio = "zu multiplizieren mit"; break;
case "letto":                                                            $messaggio = "je Bett"; break;
case "straordinario":                                                    $messaggio = "au&szlig;ergew&ouml;hnlich"; break;
case "Nuovo costo aggiuntivo settimanale":                               $messaggio = "Neue w&ouml;chentliche Aufschl&auml;ge"; break;
case "Nuovo costo aggiuntivo giornaliero":                               $messaggio = "Neue t&auml;gliche Aufschl&auml;ge"; break;
case "nº di settimane da applicare":                                    $messaggio = "Anzahl der anzuwendenen Wochen"; break;
case "nº di giorni da applicare":                                       $messaggio = "Anzahl der anzuwendenen Tage"; break;
case "non specificato":                                                  $messaggio = "nicht verf&uuml;gbar"; break;
case "Modifica la prenotazione":                                         $messaggio = "Reservierung speichern"; break;
case "Cancella la prenotazione":                                         $messaggio = "Reservierung l&ouml;schen"; break;
case "documento di tipo":                                                $messaggio = "Dokumentart"; break;
case "visualizza":                                                       $messaggio = "erstellen"; break;
case "visualizza il documento":                                          $messaggio = "Dokument anzeigen"; break;
case "Torna indietro":                                                   $messaggio = "Zur&uuml;ck"; break;
case "SI":                                                               $messaggio = "JA"; break;
case "cancella anche ciò che era stato pagato":                         $messaggio = "zus&auml;tzlich auch l&ouml;schen was bezahlt wurde"; break;
case "NO":                                                               $messaggio = "NEIN"; break;
case "La prenotazione":                                                  $messaggio = "Reservierung"; break;
case "era già stata cancellata":                                        $messaggio = "wurde bereits gel&ouml;scht"; break;
case "Prenotazione":                                                     $messaggio = "Reservierung"; break;
case "cancellata":                                                       $messaggio = "gel&ouml;scht"; break;
case "<b>non è stata cancellata</b> perchè è stata modificata nel frattempo":        $messaggio = "<b>wurde nicht gel&ouml;scht</b> da es in der Zwischenzeit ge&auml;ndert wurde"; break;
case "Si è sicuri di voler <b>cancellare</b> la prenotazione":          $messaggio = "Wollen Sie die Reservierung wirklich <b>l&ouml;schen</b>"; break;
case "Si è sicuri di voler <b>cancellare</b> le prenotazioni":          $messaggio = "Wollen Sie die Reservierung wirklich <b>l&ouml;schen</b>?"; break;
case "La data iniziale verrà cambiata dal":                             $messaggio = "Das Anfangsdatum wurde ge&auml;ndert von"; break;
case "al":                                                               $messaggio = "bis"; break;
case "La data finale verrà cambiata dal":                               $messaggio = "Das Enddatum wird ge&auml;ndert von"; break;
case "Le <div style=\"display: inline; color: red;\">date</div> sono <b>sbagliate</b>":        $messaggio = "Das gew&auml;hlte <div style=\"display: inline; color: red;\">Datum</div> ist <b>falsch</b>"; break;
case "della casa":                                                       $messaggio = "des Hauses"; break;
case "con massimo numero di occupanti":                                  $messaggio = "mit der maximalen Personenzahl"; break;
case "a":                                                                $messaggio = "zu"; break;
case "Il numero delle persone verrà cambiato da":                       $messaggio = "Die Anzahl der Personen wird ge&auml;ndert von"; break;
case "persone":                                                          $messaggio = "G&auml;ste "; break;
case "è stata <b>cancellata</b>":                                       $messaggio = "wurde <b>gel&ouml;scht</b>"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":        $messaggio = "Ver&auml;nderungen die ausgef&uuml;hrt werden m&uuml;ssen im Zeitraum <div style=\"display: inline; color: blue;\">Regel 1</div>"; break;
case "La prenotazione dal":                                              $messaggio = "Die Reservierung von"; break;
case "a nome di":                                                        $messaggio = "f&uuml;r Herrn/Frau"; break;
case "La prenotazione verrà":                                           $messaggio = "Die Reservierung wird"; break;
case "mantenuta":                                                        $messaggio = "&uuml;briggelassen"; break;
case "spostata":                                                         $messaggio = "verschoben"; break;
case "La tariffa":                                                       $messaggio = "Der Preis"; break;
case "non esiste più, cambiala prima di aggiornare":                    $messaggio = "existiert nicht mehr, &auml;ndern Sie das vor einem Update."; break;
case "<b>Non</b> è stato ancora inserito il prezzo della":              $messaggio = "Bitte geben Sie den Preis ein von"; break;
case "per la settimana dal":                                             $messaggio = "f&uuml;r die Woche von"; break;
case "per il giorno dal":                                                $messaggio = "f&uuml;r den Tag von"; break;
case "La tariffa verrà cambiata da":                                    $messaggio = "Der Preis wird ge&auml;ndert von"; break;
case "Il costo aggiuntivo":                                              $messaggio = "Die Aufschl&auml;ge werden ge&auml;ndert von"; break;
case "Il costo aggiuntivo unico":                                        $messaggio = "die einzelnen Extra-Geb&uuml;hren"; break;
case "Il costo aggiuntivo settimanale":                                  $messaggio = "Die w&ouml;chentlichen Aufschl&auml;ge"; break;
case "Il costo aggiuntivo giornaliero":                                  $messaggio = "The t&auml;glichen Extra-Geb&uuml;hren"; break;
case "non può essere moltiplicato per":                                 $messaggio = "k&ouml;nnen nicht multipliziert werden mit"; break;
case "verrà moltiplicato per":                                          $messaggio = "werden multipliziert mit"; break;
case "prima era":                                                        $messaggio = "es war"; break;
case "Le settimane del costo aggiuntivo":                                $messaggio = "Die Wochen der Aufschl&auml;ge"; break;
case "I giorni del costo aggiuntivo":                                    $messaggio = "Die Tage der Aufschl&auml;ge"; break;
case "<b>superano</b> la durata della prenotazione":                     $messaggio = "<b>&uuml;bersteigen</b> die Dauer der Reservierung"; break;
case "verranno cabiate da":                                              $messaggio = "werden ge&auml;ndert von"; break;
case "verranno cabiati da":                                              $messaggio = "wird ge&auml;ndert aus"; break;
case "verranno cabiate":                                                 $messaggio = "wird ge&auml;ndert"; break;
case "verranno cabiati":                                                 $messaggio = "werden ge&auml;ndert"; break;
case "<b>non</b> verranno cambiate":                                     $messaggio = "wird <b>nicht</b> ge&auml;ndert"; break;
case "<b>non</b> verranno cambiati":                                     $messaggio = "werden <b>nicht</b> ge&auml;ndert"; break;
case "su":                                                               $messaggio = "auf"; break;
case "Il prezzo del costo aggiuntivo":                                   $messaggio = "Der Preis der Extra-Geb&uuml;hren"; break;
case "verrà tolto":                                                     $messaggio = "werden gel&ouml;scht"; break;
case "I dati del costo aggiuntivo <b>straordinario</b> sono <div style=\"display: inline; color: red;\">errati o mancanti</div>":        $messaggio = "Die Daten f&uuml;r <b>au&szlig;ergew&ouml;hnliche</b> Extra-Geb&uuml;hren <div style=\"display: inline; color: red;\">fehlen oder sind fehlerhaft</div>"; break;
case "verrà aggiunto":                                                  $messaggio = "werden hinzugef&uuml;gt"; break;
case "come letto aggiuntivo":                                            $messaggio = "als Zusatzbett"; break;
case "Le settimane del nuovo costo aggiuntivo":                          $messaggio = "Die Wochen der neuen Aufschl&auml;ge"; break;
case "I giorni del nuovo costo aggiuntivo":                              $messaggio = "Die Tage der neuen Aufschl&auml;ge"; break;
case "Lo <div style=\"display: inline; color: red;\">sconto</div> inserito":        $messaggio = "Der eingegebene <div style=\"display: inline; color: red;\">Rabatt</div>"; break;
case "supera il costo totale senza sconto":                              $messaggio = "ist gr&ouml;&szlig;er als die gesamten Kosten ohne Rabatt"; break;
case "Lo sconto verrà cambiato da":                                     $messaggio = "Der Rabatt wird ge&auml;ndert von"; break;
case "La <div style=\"display: inline; color: red;\">caparra</div> inserita":        $messaggio = "Die eingegebene<div style=\"display: inline; color: red;\">Anzahlung</div>"; break;
case "supera il costo totale":                                           $messaggio = "ist gr&ouml;&szlig;er als die gesamten Kosten"; break;
case "La caparra verrà cambiata da":                                    $messaggio = "Die Anzahlung wird ge&auml;ndert von"; break;
case "La <div style=\"display: inline; color: red;\">caparra</div>":     $messaggio = "Die <div style=\"display: inline; color: red;\">Anzahlung</div>"; break;
case "supera il nuovo costo totale":                                     $messaggio = "ist gr&ouml;&szlig;er als die neuen kompletten Kosten"; break;
case "La cifra <div style=\"display: inline; color: red;\">pagata</div> inserita":        $messaggio = "Der eingegebene <div style=\"display: inline; color: red;\">Zahlungs</div>betrag"; break;
case "I soldi pagati verranno cambiati da":                              $messaggio = "Der gezahlte Betrag wird ge&auml;ndert auf"; break;
case "verrà <b>confermata</b>":                                         $messaggio = "wird <b>best&auml;tigt</b>"; break;
case "Verrà tolta la <b>conferma</b> alla prenotazione":                $messaggio = "Die <b>Best&auml;tigung</b> wird aus der Reservierung gel&ouml;scht"; break;
case "Il <b>commento</b> verrà cambiato":                               $messaggio = "Die <b>Bemerkung</b> wird ge&auml;ndert"; break;
case "Il <b>commento</b> verrà cancellato":                             $messaggio = "Der <b>Kommentar</b> wird gel&ouml;scht"; break;
case "Continua":                                                         $messaggio = "Weiter"; break;
case "modificata":                                                       $messaggio = "ge&auml;ndert"; break;
case "<b>non è stata modificata</b> perchè la tabella prenotazioni è cambiata nel frattempo":        $messaggio = "<b>wurde nicht ge&auml;ndert</b>, weil die Reservierungstabelle inzwischen ge&auml;ndert wurde."; break;
case "verrà cambiato da":                                               $messaggio = "wird ge&auml;ndert von"; break;
case "con costo agg.":                                                   $messaggio = "mit Aufschl&auml;ge"; break;
case "Cliente":                                                          $messaggio = "Gast"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":        $messaggio = "Es gibt keine Zeitr&auml;ume in Zuweisungsregel 1 die es erlauben eine Reservierung einzutragen f&uuml;r den Kunden"; break;
case "Prenotazione non confermata":                                      $messaggio = "Reservierung wurde nicht best&auml;tigt"; break;
case "Inserita dall'utente":                                             $messaggio = "Eingegeben von"; break;
case "Si considererà l'utente":                                         $messaggio = "Benutzer"; break;
case "come colui che ha inserito la prenotazione":                       $messaggio = "wird eingetragen als der der die Reservierung eingetragen hat"; break;
case "Non si possono inserire altri costi":                              $messaggio = "Sie k&ouml;nnen keine weiteren Geb&uuml;hren erfassen"; break;
case "in questo periodo, già":                                          $messaggio = "in dieser Periode"; break;
case "presenti":                                                         $messaggio = "derzeit"; break;
case "Non si puo inserire il costo aggiuntivo":                          $messaggio = "Die Extra-Geb&uuml;hren"; break;
case "in questo periodo":                                                $messaggio = "kann im Zeitraum nicht eingef&uuml;gt werden"; break;
case "Settimane":                                                        $messaggio = "Wochen"; break;
case "Giorni":                                                           $messaggio = "Tage"; break;
case "mostra":                                                           $messaggio = "anzeigen"; break;
case "nascondi":                                                         $messaggio = "verstecken"; break;
case "numeri diversi":                                                   $messaggio = "verschiedene Nummern"; break;
case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":        $messaggio = "Sie k&ouml;nnen nicht mehr als eine Extra-Geb&uuml;hr einf&uuml;gen, die prozentual vom Gesamtpreis berechnet wird"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":      $messaggio = "Die Wochen ausw&auml;hlen, f&uuml;r die die Extra-Geb&uuml;hr angewendet werden sollen"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":          $messaggio = "Die Tage ausw&auml;hlen, f&uuml;r die die Extra-Geb&uuml;hr angewendet werden sollen."; break;
case "Si deve inserire il numero delle persone per il costo aggiuntivo": $messaggio = "F&uuml;r diese Extra-Geb&uuml;hr ist die Anzahl der G&auml;ste n&ouml;tig"; break;
case "Non si possono inserire altri costi":                              $messaggio = "Sie k&ouml;nnen keine weiteren Geb&uuml;hren erfassen"; break;
case "in questo periodo, già":                                          $messaggio = "in dieser Periode"; break;
case "presenti":                                                         $messaggio = "derzeit"; break;
case "totale":                                                           $messaggio = "Summe"; break;
case "registra entrata":                                                 $messaggio = "CheckIn"; break;
case "cancella entrata":                                                 $messaggio = "l&ouml;sche CheckIn"; break;
case "registra uscita":                                                  $messaggio = "CheckOut"; break;
case "cancella uscita":                                                  $messaggio = "l&ouml;sche CheckOut"; break;
case "Metodo pagamento caparra":                                         $messaggio = "Anzahlungsart"; break;
case "Il metodo di pagamento della caparra verrà cambiato a":           $messaggio = "Anzahlungsart wurde ge&auml;ndert auf"; break;
case "Metodo di pagamento":                                              $messaggio = "Zahlungsart"; break;
case "metodo di pagamento":                                              $messaggio = "Zahlart"; break;
case "Prova di nuovo":                                                   $messaggio = "Bitte neu versuchen"; break;
case "Modifica nell'anno precedente":                                    $messaggio = "&Auml;nderungen im vergangenen Jahr"; break;
case "Orario entrata stimato":                                           $messaggio = "gew&uuml;nschte CheckIn Zeit"; break;
case "L'orario stimato di entrata verrà cambiato a":                    $messaggio = "Die gew&uuml;nschte CheckIn Zeit wurde ge&auml;ndert auf"; break;
case "Codice prenotazione":                                              $messaggio = "Buchungskode"; break;
case "rigenera":                                                         $messaggio = "neuen Kode erstellen"; break;
case "Non si è potuto spostare la prenotazione per la registrazione dell'entrata":        $messaggio = "Es ist nicht m&ouml;glich die Buchung w&auml;hrend des CheckIn zu ver&auml;ndern"; break;
case "Cambia cliente":                                                   $messaggio = "Gast &auml;ndern"; break;
case "Nuovo titolare della prenotazione":                                $messaggio = "Neuer Ansprechpartner zur Buchung"; break;
case "cliente numero":                                                   $messaggio = "Kundennummer"; break;
case "Il titolare della prenotazione":                                   $messaggio = "der Ansprechpartner der Buchung"; break;
case "Il titolare delle prenotazioni":                                   $messaggio = "der Titel der Buchungen"; break;
case "Cliente non trovato":                                              $messaggio = "Gast nicht gefunden"; break;
case "Annulla":                                                          $messaggio = "Abbrechen"; break;
case "Prenotazioni vicine":                                              $messaggio = "Abgeschlossene Buchungen"; break;
case "numero":                                                           $messaggio = "Anzahl"; break;
case "La prenotazione numero":                                           $messaggio = "Die Buchungsnummer"; break;
case "non esiste":                                                       $messaggio = "ist nicht vorhanden"; break;
case "Ospiti della prenotazione":                                        $messaggio = "Buchungen G&auml;ste"; break;
case "Modifica gli ospiti":                                              $messaggio = "Gast &auml;ndern"; break;
case "nato":                                                             $messaggio = "geboren"; break;
case "nata":                                                             $messaggio = "geborn"; break;
case "il":                                                               $messaggio = "die"; break;
case " a":                                                               $messaggio = " in"; break;
case "scade":                                                            $messaggio = "g&uuml;ltig"; break;
case "Codice fiscale":                                                   $messaggio = "Steuernummer"; break;
case "Origine":                                                          $messaggio = "Quelle"; break;
case "L'origine della prenotazione verrà cambiata a":                   $messaggio = "Der Buchungsurspung wird ge&auml;ndert auf"; break;
case "Modifica o cancella le prenotazioni":                              $messaggio = "Bearbeitung f&uuml;r Buchung No.:"; break;
case "Modifica le prenotazioni":                                         $messaggio = "Speichern der &Auml;nderungen"; break;
case "Cancella le prenotazioni":                                         $messaggio = "L&ouml;schen der Buchung"; break;
case "della prenotazione":                                               $messaggio = "aus Buchung"; break;
case "per la prenotazione":                                              $messaggio = "f&uuml;r Buchung"; break;
case "Data inserimento":                                                 $messaggio = "Erfasssungsdatum"; break;
case "Partita iva":                                                      $messaggio = "UstId."; break;
case "Commissioni":                                                      $messaggio = "Nachl&auml;sse"; break;
case "Ricalcola le commissioni in base alla nuova tariffa":              $messaggio = "Nachl&auml;sse automatisch zum Tarif berechnen"; break;
case "Le commissioni verranno cambiate da":                              $messaggio = "Nachl&auml;sse werden ge&auml;ndert von"; break;
case "tasse":                                                            $messaggio = "Steuern"; break;
case "Il prezzo totale cambierà da":                                    $messaggio = "Der Gesamtpreis wird ge&auml;ndert von"; break;
case "saldo di":                                                         $messaggio = "Offene Posten"; break;
case "Altre prenotazioni dello stesso cliente nello stesso periodo":     $messaggio = "Buchungen des Gastes im gleichen Zeitraum"; break;
case "tutte":                                                            $messaggio = "alle"; break;
case "Attenzione":                                                       $messaggio = "Warnung"; break;
case "vi sono altre prenotazioni dello stesso cliente nello stesso periodo che ancora non sono state pagate":        $messaggio = "es sind weitere Buchungen im selben Zeitraum des Gastes vorhanden, die noch nicht bezahlt sind"; break;
case "Il saldo totale pagato sarà di":                                  $messaggio = "Der Gesamtbetrag bel&auml;uft sich auf"; break;
case "ln.":  					$messaggio = "ln."; break;
case "Costo aggiuntivo unico":  		$messaggio = "Single extra cost"; break;
case "°</b> piano":  				$messaggio = "</b>"; break;
case "della tariffa":  				$messaggio = "of rate"; break;
case "del totale":  				$messaggio = "of total"; break;
case "della caparra":  				$messaggio = "of deposit"; break;
case "del resto caparra":  			$messaggio = "of deposit rest"; break;
case "di base":  				$messaggio = "of base"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata già registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-in already registered"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata non registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-in not registered"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita già registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-out already registered"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita non registrato, registrare prima l'entrata":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-out not registered, register check-in before"; break;
case "Normalmente le prenotazioni già iniziate e quelle che hanno registrato l'orario di entrata non vengono spostate":	$messaggio = "Normally already begun reservations and the ones that have done check-in are not moved"; break;
case "muovendo anche le prenotazioni iniziate dopo il":	$messaggio = "moving also reservations begun after"; break;
case "considerate fisse perchè <div style=\"display: inline; color: red;\">ad oggi già iniziate</div>":	$messaggio = "considered fixed because <div style=\"display: inline; color: red;\">as of today already begun</div>"; break;
case "è incompatibile con la tariffa selezionata":	$messaggio = "is incompatible with selected rate"; break;
case "non può essere applicato":  		$messaggio = "can't be applied"; break;
case "Non si può cambiare l'assegnazione di una prenotazione che si trova <div style=\"display: inline; color: red;\">tra due anni</div>":	$messaggio = "You can't change the assignment of a reservation that is <div style=\"display: inline; color: red;\">between two years</div>"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "with selected extra costs"; break;
case "I beni richiesti dal costo":  		$messaggio = "Goods needed by cost"; break;
case "non sono disponibili nell'inventario":  	$messaggio = "are not available in the inventory"; break;
case "<b><big>i</big></b>":  			$messaggio = "<b><big>i</big></b>"; break;
case "pren.":  					$messaggio = "res."; break;
case "Si deve inserire il <span class=\"colred\">numero delle persone</span> per la tariffa selezionata":	$messaggio = "The <span class=\"colred\">number of people</span> must be inserted for the selected rate"; break;
case "i beni richiesti alla registrazione dell'entrata":	$messaggio = "items needed by check-in"; break;
case "della tariffa fissa":  			$messaggio = "of fixed rate"; break;
case "di una persona":  			$messaggio = "of one person"; break;
case "non può essere moltiplicato per più di":	$messaggio = "can not be multiplied by more than"; break;
case "Nuovo costo aggiuntivo":  		$messaggio = "New extra cost"; break;
case "aggiungi promemoria per l'entrata":  	$messaggio = "add a reminder for checkin"; break;
case "aggiungi promemoria per l'uscita":  	$messaggio = "add a reminder for checkout"; break;
case "Verrà aggiunto un <b>promemoria</b> per l'<em>entrata</em>":	$messaggio = "A <b>reminder</b> for <em>checkin</em> will be added"; break;
case "Verrà aggiunto un <b>promemoria</b> per l'<em>uscita</em>":	$messaggio = "A <b>reminder</b> for <em>checkout</em> will be added"; break;
case "Promemoria":  				$messaggio = "Reminder"; break;
case "La <b>tariffa</b> richiesta è <span class=\"colred\">chiusa</span> in questo periodo":	$messaggio = "The requested <b>rate</b> is <span class=\"colred\">closed</span> in this period"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>